CharSet

Struct CharSet 

pub struct CharSet { /* private fields */ }
Represents an ordered set of code points.

TODO(kpozin): Add factory method that takes lazy Iterator<Item = char> instead of Vec. TODO(kpozin): Enforce char values.

Implementations

Source

impl CharSet

pub fn new(code_points: Vec<u32>) -> CharSet

pub fn contains(&self, c: u32) -> bool

pub fn is_empty(&self) -> bool

pub fn len(&self) -> usize

Returns the number of code points in the set.

pub fn iter(&self) -> impl Iterator<Item = char> + '_

Iterate over all the characters in the the CharSet in code point order.